#
# spec file for package streamlink
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global         flavor %nil
%if "%{flavor}" == "test"
%define         psuffix -test
%else
%define         psuffix %nil
%endif
Name:           streamlink%{psuffix}
Version:        7.1.3
Release:        1.1
Summary:        Program to pipe streams from services into a video player
License:        Apache-2.0 AND BSD-2-Clause
URL:            https://streamlink.github.io/
Source:         https://github.com/%{name}/%{name}/releases/download/%{version}/streamlink-%{version}.tar.gz
Source1:        https://github.com/%{name}/%{name}/releases/download/%{version}/streamlink-%{version}.tar.gz.asc
Source2:        https://keyserver.ubuntu.com/pks/lookup?op=get&search=0xcdac41b9122470faf357a9d344448a298d5c3618#/streamlink.keyring
BuildRequires:  fdupes
BuildRequires:  python3-PySocks >= 1.5.6
BuildRequires:  python3-Sphinx >= 4
BuildRequires:  python3-certifi
BuildRequires:  python3-devel >= 3.9
BuildRequires:  python3-isodate
BuildRequires:  python3-lxml >= 4.6.4
BuildRequires:  python3-mypy
BuildRequires:  python3-pip >= 9
BuildRequires:  python3-pycountry
BuildRequires:  python3-pycryptodome >= 3.4.3
BuildRequires:  python3-requests >= 2.26
BuildRequires:  python3-setuptools
BuildRequires:  python3-trio >= 0.25.0
BuildRequires:  python3-trio-typing
BuildRequires:  python3-trio-websocket >= 0.9.0
BuildRequires:  python3-urllib3 >= 1.26.0
BuildRequires:  python3-versioningit >= 2.0.0
BuildRequires:  python3-websocket-client >= 1.2.1
BuildRequires:  python3-wheel

%if "%{flavor}" == "test"
BuildRequires:  python3-freezegun >= 1.0.0
BuildRequires:  python3-pytest >= 8.0.0
BuildRequires:  python3-pytest-trio
BuildRequires:  python3-requests-mock
BuildRequires:  streamlink = %{version}
%endif

Requires:       python3-PySocks >= 1.5.6
Requires:       python3-certifi
Requires:       python3-isodate
Requires:       python3-lxml >= 4.6.4
Requires:       python3-pycountry
Requires:       python3-pycryptodome >= 3.4.3
Requires:       python3-requests >= 2.26
Requires:       python3-trio >= 0.22.0
Requires:       python3-trio-websocket >= 0.9.0
Requires:       python3-urllib3 >= 1.26.0
Requires:       python3-websocket-client >= 1.2.1
Conflicts:      python3-PySocks = 1.5.7
# the behaviour of libsolv changed, so we now have to suggest the one we actually want
# if no player is preinstalled or in the same install command
Recommends:     (vlc or mpv)
Suggests:       vlc
Suggests:       ffmpeg
BuildArch:      noarch

%description
Streamlink is a command-line utility which pipes video streams from various
services into a video player, such as VLC. The main purpose of Streamlink is to
avoid resource-heavy and unoptimized websites, while still allowing the user to
enjoy various streamed content.

%prep
%autosetup -n streamlink-%{version}

%build
%python3_build

%if "%{flavor}" != "test"
%install
%python3_install --root %{buildroot}
%fdupes -s %{buildroot}
%endif

%if "%{flavor}" == "test"
%check
pytest
%endif

%if "%{flavor}" != "test"
%files
%license LICENSE
%doc AUTHORS CHANGELOG.md MANIFEST.in README.md
%{_bindir}/%{name}
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}_cli
%{python3_sitelib}/%{name}-%{version}*-info
%_mandir/man*/*
%{_datadir}/bash-completion/completions/streamlink
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_streamlink
%endif

%changelog
* Mon Feb 17 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 7.1.3:
  * Fixed: validate.contains() to allow all kinds of Container object inputs
  * Docs: replaced Windows and Linux AppImage nightly builds with preview builds triggered on each commit to master
  * Docs: added optional/secondary Linux AppImage builds with FFmpeg being bundled
  * Tests: bumped freezegun requirement to >=1.5.0
  * Updated plugins:
  - ceskatelevize: rewritten and fixed plugin
  - nos: fixed validation schema, updated matcher
  - pandalive: fixed user_id retieval, updated matcher
  - pluzz: fixed video ID schemas
  - streamable: removed plugin
  - tv4play: removed plugin
  - twitch: refactored TwitchAPI class and access token retrieval
  - wwenetwork: rewritten and fixed plugin
* Mon Jan 27 2025 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 7.1.2:
  * Updated plugins:
    + various: fixed access of URL matcher regex capture groups, affecting abematv, ard_mediathek, bbiplayer, dailymotion, picarto, streann (#6364, #6368)
    + chzzk: added support for clips (#6389)
    + dailymotion: added support for lequipe.fr (#6372)
    + kick: fixed 403 HTTP errors, fixed VOD URL matcher (#6384)
    + nicolive: fixed authentication (#6378)
    + tiktok: rewritten plugin, fixed live streams, added VODs (#6381)
  * Fixed: --show-matchers=pluginname not working when plugins are loaded lazily (#6361)
  * Added: --show-matchers=pluginname CLI argument (#6287)
  * Updated: Streamlink and Plugin constructors to allow both Mapping and Options as options types (#6311)
  * Fixed: uncaught DASH errors if FFmpeg is unavailable (#6306)
  * As a side effect, if FFmpeg is unavailable, DASH streams will only return one sub-stream of the video and/or audio streams that would be muxed otherwise.
  * Fixed: incorrect DASH segment duration in timeline manifests (#6323)
  * Fixed: dynamic DASH streams incorrectly requiring the publishTime and availabilityStartTime attributes (#6324)
  * Fixed: incorrect DASH segment and manifest base-URL joining (#6328, #6338)
  * Fixed: matchers and arguments objects being shared in inherited Plugin classes (#6297, #6298)
  * Updated plugins:
    + various: replaced verbose URL matcher regexes of most plugins with multiple simple ones (#6285)
    + bilibili: updated schema to include MPEG-TS HLS streams (#6332)
    + bilibili: added back high-res HTTPStream streams from the v1 API with higher priority (#5782)
    + mangomolo: replaced media.gov.kw with 51.com.kw (#6353)
    + soop: rewritten authentication (#6321)
    + vkplay: renamed to vkvideo and updated matcher (#6319)
    + welt: fixed schema (#6301)
  * Build: removed typing-extensions from runtime dependencies (#6314)
* Mon Nov  4 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 7.0.0:
  * BREAKING: dropped support for EOL Python 3.8 (Win 7/8 are now unsupported)
  * BREAKING/CLI: removed deprecated config file and plugin config file paths
  * BREAKING/CLI: removed deprecated plugin sideloading paths
  * BREAKING/CLI: removed deprecated --force-progress CLI argument
  * BREAKING/CLI: removed deprecated stream-type related CLI arguments
  - --hls-segment-attempts
  - --hls-segment-threads
  - --hls-segment-timeout
  - --hls-timeout
  - --http-stream-timeout
  * BREAKING/API: removed deprecated stream-type related session options
  - hls-segment-attempts
  - hls-segment-threads
  - hls-segment-timeout
  - hls-timeout
  - dash-segment-attempts
  - dash-segment-threads
  - dash-segment-timeout
  - dash-timeout
  - http-stream-timeout
  * BREAKING/API: removed deprecated import paths for HTTPSession and HTTPAdapters
  * BREAKING/API: removed deprecated import paths for NoPluginError, NoStreamsError, PluginError and Plugin
  * BREAKING/packaging: dropped "32 bit" Windows x86 and Linux AppImage i686 builds
  * Removed: flawed implementation of VLC-specific player variables
  * Deprecated: --verbose-player CLI argument in favor of --player-verbose
  * Deprecated: --fifo CLI argument in favor of --player-fifo
  * Added: warning messages for deprecated/suppressed plugin arguments
  * Fixed: errors on missing stdin file descriptor
  * Fixed: --interface not having an effect on custom HTTPAdapters
  * Updated plugins: afreeca, ruv, tv3cat
  * Docs: updated documentation of various CLI arguments
  * Chore: updated typing annotations (PEP 563, PEP 585, PEP 604, PEP 613)
  * Chore: reformatted the whole code base using ruff
  * Build: bumped trio dependency to >=0.25.0,<1 on Python >= 3.13
- require python-trio >= 0.25, so we are ready for python313
- suggest vlc, so it will be prefered over mpv (as libsolv solves it in alphabetical order)
* Tue Oct  1 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 6.11.0:
  * Deprecated: --record-and-pipe=... in favor of --stdout --record=...
    (and explicitly disallowed --stdout --output=...)
  * Fixed: error when setting both --http-no-ssl-verify and --http-disable-dh
  * Fixed: --player-passthrough without a resolved default --player
  * Fixed: error when stdout/stderr file descriptors are missing
  * Updated: webbrowser API's Chrome devtools protocol to latest version
  * Updated plugins:
  - crunchyroll: removed plugin
  - dlive: fixed missing stream URL signature
  - facebook: removed plugin
  - mildom: removed plugin
  - tvrby: removed plugin
  - tvrplus: removed plugin
  - twitch: fixed client-integrity token acquirement
  - vk: fixed API params and validation schema
  - webtv: removed plugin
  - zengatv: removed plugin
  - zhanqi: removed plugin
  * Tests: removed pytest-asyncio dependency
* Fri Sep 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 6.10.0:
  * Added: official support for Python 3.13
  * Added: --logformat and --logdateformat
  * Added: --ffmpeg-loglevel
  * Fixed: continuous logging errors when stdout stream was closed on the reading end
  * Fixed: HTTP proxy config being used when getting webbrowser API's websocket IPC address
  * Updated plugins:
  - booyah: removed plugin
  - douyin: fixed validation schema
  - galatasaraytv: removed plugin
  - idf1: removed plugin
  - linelive: removed plugin
  - pandalive: fixed missing HTTP headers
  - tiktok: fixed schema of inaccessible streams
  - youtube: disabled VODs, as they are currently non-functional
  * Docs: bumped sphinx-design >=0.5.0,<=0.6.1, enabling sphinx >=8.0.0
  * Tests: fixed pytest-asyncio warnings
- remove last bits of supporting leap (as dependencies are missing anyway)
* Mon Aug 12 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 6.9.0:
  * Added: streamlink.plugin.api.webbrowser subpackage with the aws_waf module
  * Added: max_buffer_size kwarg to CDPClient.session()
  * Added: webbrowser User-Agent header override in headless mode
  * Changed: default value of --webbrowser-headless from True to False
  * Changed: unicode characters to be unescaped in JSON output, if possible
  * Fixed: potential character encoding issues in Streamlink's logger
  * Updated plugins:
  - nicolive: updated plugin matcher
  - okru: fixed validation schema
  - radionet: removed plugin
  - sportschau: fixed plugin (HLS streams with packed audio streams remain unsupported)
  - tiktok: fixed room ID validation schema
  - tvp: added support for sport.tvp.pl
  - twitch: added --twitch-force-client-integrity
  - twitch: fixed broken client-integrity token decoding+parsing
  - twitch: removed the headless=False override
  - vimeo: removed error messages for unsupported DASH streams
  - vk: fixed validation schema
  - vtvgo: resolved AWS Web Application Firewall bot detection
  - yupptv: fixed plugin, added ad filtering
* Fri Jul 12 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 6.8.3:
  * tiktok: new plugin
  * twitch: fixed channel names with uppercase characters
* Fri Jul  5 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 6.8.2:
  * douyin: new plugin
  * huya: fixed stream URLs
  * pluzz: fixed API URL, stream tokens and validation schemas
  * twitch: added info log messages about ad break durations
  * twitch: fixed clip URLs
  * twitch: fixed discontinuity warning spam in certain circumstances
  * vidio: fixed stream tokens, added metadata
* Mon Jun 17 2024 Richard Rahl <rrahl0@disroot.org>
- update to 6.8.1:
  * Fixed: failed HTTPAdapter tests on some OpenSSL configurations
- update to 6.8.0:
  * sha256 checksum to log message when side-loading plugins
  * SSLContextAdapter to streamlink.session.http
  * Deprecated: old re-exports in streamlink.plugins package
  * Updated plugins: bilibili, chzzk cnbce, kick, tf1, tvp, welt
* Mon May 13 2024 Richard Rahl <rrahl0@disroot.org>
- update to 6.7.4:
  * Updated plugins
  * Build: removed exceptiongroup dependency on Python >= 3.11
* Tue May  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Fix the testsuite, pytest >= 8 is required.
* Mon Apr 22 2024 Richard Rahl <rrahl0@disroot.org>
- update to 6.7.3:
  * Fixed: file output paths being able to exceed max file/directory name length
  * Fixed: propagation of KeyboardInterrupt/SystemExit in streamlink.webbrowser
  * Fixed: compatibility with exceptiongroup<=1.1.1
  * Fixed: plugin.api.validate.parse_qsd input type validation
  * Updated plugins
  * Tests: fixed test failure when running tests from the bdist build directory
- add mpv as an alternative
- disable tests for now, as they break for no apparent reason
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- update to 6.5.1:
  * Fixed: file output path log message on py38/py39
  * Improved: warning message when using quoted player paths (in
    config files)
  * artetv: updated API response validation schema
  * atresplayer: updated API response validation schema
  * bigo: reimplemented plugin
  * bilibili: fixed stream resolving issues on channels with
    custom layouts
  * huya: added stream CDN availability check
  * twitch: disabled Chromium headless mode on client-integrity
    token acquirement
  * vidio: fixed missing API request cookies
  * zattoo: fixed audio/video sync issues
- add keyring for gpg validation
* Wed Jan 10 2024 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to version 6.5.0
  * Fixed: UserWarning being emitted by recent pycountry releases when parsing certain language codes (#5722)
  * Fixed: trace logging setup in WebsocketClient implementation (#5705)
  * Updated plugins:
  * btv: switched to HLS multivariant playlists (#5698)
  * gulli: rewritten plugin (#5725)
  * twitch: removed/disabled --twitch-disable-reruns (#5704)
  * twitch: enabled check_streams HLS option, to ensure early stream availability without querying the delayed Twitch API (#5708)
  * twitch: removed unnecessary Twitch API error messages for offline channels (#5709)
  * wasd: removed plugin (#5711)
  * Build: added support for versioningit >=3.0.0, with backward compatibility (#5721)
* Sun Dec  3 2023 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to version 6.4.2
  + See https://github.com/streamlink/streamlink/blob/master/CHANGELOG.md
* Mon Oct 23 2023 Hakim Zulkufli <hakim.zulkufli@gmail.com>
- Update to version 6.2.1:
  + Added: official support for Python 3.12 (#5576)
  + Fixed plugins: goodgame (#5557), nos (#5565), pandalive (#5569), wwenetwork (#5559)
  + Build: added custom setuptools build-backend override which fixes issues with building Windows-specific wheels (#5558)
- Update to version 6.2.0:
  + Added: --player-env CLI argument (#5535)
  + Added: OpenSSL version to debug log output (#5506)
  + Updated: segmented stream internals and typing (#5504, #5507)
  + Updated: internal HLS tag parsing setup and parser state (#5513, #5521)
  + Fixed: HLS streams not ending on playlist reload with endlist tag and no new segments (#5538)
  + Fixed: missing file encoding when writing a log file (#5532)
  + Added plugins: piaulizaportal (#5508)
  + Fixed plugins: hiplayer (#5534), nicolive (#5529), pluto (#5551)
  + Docs: added list of supported metadata variables for each plugin (#5517, #5519)
- Update to version 6.1.0:
  + Added: --hls-segment-queue-threshold for being able to configure when to stop HLS streams early on missing segments (#5478)
  + Fixed: config file parsing issues and made parsing argument values more strict (#5484)
  + Fixed: race condition when reading and validating the FFmpeg version string (#5480)
  + Fixed plugins: atresplayer (#5477)
  + Docs: added code examples for the removal of Streamlink.{g,s}et_plugin_option (#5497)
  + Build: fixed entry-points config issues with setuptools 68.1.0 (#5500)
- Update to version 6.0.1:
  + Added: missing options argument to Streamlink.streams() (#5469)
  + Fixed: migration docs and the 6.0.0 changelog of the Streamlink.{g,s}et_plugin_option() removal (#5471)
  + Fixed plugins: huya (#5467)
  + Docs: updated build-dependencies and the furo theme (#5464, #5465)
- Update to version 6.0.0:
  + BREAKING: dropped support for Python 3.7 (#5302)
  + BREAKING: turned --player CLI argument into a player-path-only argument (#5305, #5310)
  + BREAKING: removed deprecated {filename} variable from --player-args (#5310)
  + BREAKING/API: removed support for the deprecated Plugin.can_handle_url() / Plugin.priority() classmethods (#5403)
  + BREAKING/API: removed deprecated compatibility wrapper for the Plugin constructor (#5402)
  + BREAKING/API: removed Streamlink.{g,s}et_plugin_option() (#5033)
  + BREAKING/API: removed deprecated global plugin arguments (#5033)
  + BREAKING/API: removed deprecated streamlink.plugin.api.validate.text (#5404)
  + BREAKING/API: fixed/changed signatures of HTTPStream, HLSStream and HLSStream.parse_variant_playlist() (#5429)
  + BREAKING/packaging: new signing key 44448A298D5C3618 (#5449)
  + Added: experimental streamlink.webbrowser API for extracting data from websites using the system's Chromium-based web browser (#5380, #5381, #5386, #5388, #5410)
  + See the --webbrowser, --webbrowser-executable and related CLI arguments for more
  + Added: client-integrity token support to Twitch plugin using the streamlink.webbrowser API (currently only used as a fallback when acquiring the access token fails) (#5414)
  + Added: {playertitleargs} variable to --player-args (#5310)
  + Added: with_{video,audio}_only parameters to DASHStream.parse_manifest() (#5340)
  + Changed: HLS streams to stop early on missing EXT-X-ENDLIST tag when polling the playlist doesn't yield new segments for twice its targetduration value (#5330)
  + Fixed: regex of optional protocol plugin parameters (#5367)
  + Fixed plugins: lrt (#5444), mediavitrina (#5376), mitele (#5436), NRK (#5408), pluzz (#5369), rtvs (#5443), showroom (#5390), turkuvaz (#5374), vimeo (#5335), youtube (#5351)
  + Docs: added migrations page for further guidance on resolving breaking changes (#5433)
  + Docs: split up, updated and improved API docs (#5398)
  + Build: moved project metadata to pyproject.toml (PEP621) (#5438)
  + Dependencies: added trio (#5386), trio-websocket and typing-extensions (#5388), and removed importlib_metadata (#5302)
* Mon Jun  5 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to version 5.5.1:
  + Fixed: shifting time offset when reloading HLS playlists (#5321)
  + Fixed: import of create_urllib3_context on urllib3 <2.0.0 (#5333)
  + Fixed: Vimeo plugin (#5331)
  5.5.0:
  + Added: --no-config (#5314)
  + Added: --player-external-http-interface (#5295)
  + Fixed: M3U8 attribute parsing issue (#5307)
  + Fixed: various minor plugin issues (#5291, #5299, #5306)
  + Build: bumped urllib3 to >=1.26.0,<3 and fixed compatibility
    issues with urllib3 >=2.0.0 (#5326, #5325)
  + Docs: bumped furo theme to 2023.03.27 (#5301)
  + Docs: bumped build dependencies sphinx >=5.0.0,<7, myst-parser
    >=1.0.0,<2 and sphinx-design >=0.4.1,<1 (#5301)
  5.4.0:
  + Added: --progress CLI argument and deprecated --force-progress (#5268)
  + Added: --dash-manifest-reload-attempts and respective session option (#5208)
  + Improved: DASH segment availability/download logging (#5214, #5235)
  + Refactored: DASH parser + stream implementation (#5221, #5224, #5225, #5244, #5248)
  + Fixed: DASH segment template numbers and availability times (#5213, #5217, #5233)
  + Fixed: DASH manifest mediaPresentationDuration and period duration (#5226)
  + Fixed: DASH manifest suggestedPresentationDelay (#5215)
  + Fixed: various DASH manifest parsing bugs (#5247)
  + Fixed: DASH timeline IDs not being unique (#5199)
  + Fixed: DASH substreams not having synced timelines (#5262)
  + Fixed: queued DASH segments being downloaded after closing the stream (#5236, #5237)
  + Fixed: incorrect min/max values of certain numeric CLI arguments (#5239)
  + Fixed: all naive datetime objects and made them timezone-aware (#5210)
  + Fixed: TV5monde plugin with new implementation (#5206)
  + Fixed: Steam plugin missing CDN auth data in stream URLs (#5222)
  + Fixed: Vimeo plugin's playerConfig regex (#5227)
  + Fixed: VKplay plugin's validation schema (#5251)
  + Fixed: Twitcasting plugin with new implementation (#5255)
  + Tests: fixed setuptools/pkg_resources DeprecationWarnings (#5167, #5230)
  + Tests: fixed ResourceWarnings due to stale file handles (#5242)
  + Added plugins: indihometv (#5266), telemadrid (#5212)
  + Removed plugins: nbcnews (#5279), useetv (#5266)
* Sat Mar  4 2023 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to version 5.3.1. Breaking changes:
  + BREAKING: removed avconv (libav) from FFmpeg fallback list (#4826)
  + BREAKING/API: removed Plugin.bind() and changed the signature of the Plugin class constructor (#4768)
    A compatibility wrapper for these interface changes has temporarily been added in order to keep third-party plugin implementations working.
    Please see the deprecation docs for more details.
  + BREAKING/API: changed the return value of Session.resolve_url() (#4768)
    Please see the deprecation docs for more details.
  + BREAKING/API: removed HTTPSession.parse_*() methods (#4803)
* Wed Jul 27 2022 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to version 4.2.0
  + Added: parsed multivariant playlist reference to HLSStream and MuxedHLSStream (#4568)
  + Fixed: unnecessary delay when closing DASHStreams (#4630)
  + Fixed: FFmpegMuxer not closing sub-streams concurrently (#4634)
  + Fixed: threading issue when closing WebsocketClient connections (#4608)
  + Fixed: handling of PluginErrors when outputting JSON data via --json (#4590)
  + Fixed: broken YouTube plugin when setting custom authentication headers (#4576)
  + Fixed: "source" Twitch VODs not being considered "best" (#4625)
  + Fixed: and rewritten FilmOn plugin (#4573)
  + Fixed: websocket issue in Twitcasting plugin (#4608, #4628)
  + Fixed: VK plugin (#4613, #4638)
  + Fixed: various other plugin issues (see full changelog)
  + New plugins: Aloula (#4572)
  + Removed plugins: Eltrecetv (#4593)
- Update package description and requirements
* Thu Jun  9 2022 Ben Greiner <code@bnavigator.de>
- Update to version 4.1.0
  * Improved: decryption of HLS streams (#4533)
  * Improved: HLS playlist parsing (#4540, #4552)
  * Improved: string representations of Stream implementations
    (#4521)
  * Fixed: new YouTube consent dialog (#4515)
  * Fixed: crunchyroll plugin (#4510)
  * Fixed: nicolive email logins (#4553)
  * Fixed: threading issue when closing segmented streams (#4517)
  * Removed: suppression of InsecureRequestWarning (#4525)
  * New plugins: blazetv (#4548), hiplayer (#4507), useetv (#4536)
  * Removed plugins: rotana (#4512)
- The real name of the patch was python-requests-version.patch
- Update requirements.
* Sat May 21 2022 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Dropped python-version-requests.patch
  + streamlink now only builds on TW where we have requests-2.27
* Sat May 21 2022 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to version 4.0.1
  + Major breaking changes! Please review the changelog thoroughly.
    https://streamlink.github.io/changelog.html#streamlink-4-0-0-2022-05-01
  + dropped support for Python 3.6 (#4442)
  + removed streamlink.plugin.api.utils module (#4467)
* Sat Jan 15 2022 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to version 3.0.3
  + Major breaking changes! Please review the changelog thoroughly.
    https://streamlink.github.io/changelog.html#streamlink-3-0-3-2021-11-27
  + dropped support for RTMP, HDS and AkamaiHD streams
  + removed related CLI arguments
  + switched from HTTP to HTTPS for all kinds of scheme-less input URLs.
  + changed Session.resolve_url() and Session.resolve_url_no_redirect()
* Mon Aug 30 2021 Simon Puchert <simonpuchert@alice.de>
- Add python-requests-version.patch:
  * Revert a commit that increased the version requirements as the
    required version is not available in Factory.
* Mon Aug 16 2021 Simon Puchert <simonpuchert@alice.de>
- Update to version 2.3.0:
  * new plugin URL matching API
  * HLS media initialization section (fragmented MPEG-4 streams)
  * Fixed: YouTube channel URLs, premiering live streams,
    added API fallback
  * Removed plugins: canalplus, dommune, liveedu, periscope,
    powerapp, rtlxl, streamingvideoprovider, teleclubzoom, tigerdile
- Update to version 2.2.0:
  * Changed default custom plugins directory path:
    `${XDG_DATA_HOME:-${HOME}/.local/share}/streamlink/plugins`
  * Deprecated (old) config file paths and custom plugins directory paths:
    `${XDG_CONFIG_HOME:-${HOME}/.config}/streamlink/plugins` and
    `${HOME}/.streamlinkrc`.
  * Implemented `--logfile` CLI argument
  * Fixed Youtube 404 errors by dropping private API calls (plugin rewrite)
  * Fixed: Twitch clips and hosted channel redirection
  * Fixed: Olympicchannel plugin
  * Fixed various Zattoo plugin issues
  * Fixed: HTTP responses with truncated body and mismatching content-length header
  * Fixed: scheme-less URLs with address:port for `--http-proxy`, etc.
  * Fixed rendered man page path on Sphinx 4
  * Added plugins: mildom.com, booyah.live, mediavitrina.ru
  * Removed plugins: ine.com, playtv.fr
- Updated requirements according to upstream build instructions
* Mon May 31 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 2.1.2
  * Fixed: youtube 404 errors (#3732), consent dialog (#3672) and added short URLs (#3677)
  * Fixed: picarto plugin (#3661)
  * Fixed: euronews plugin (#3698)
  * Fixed: bbciplayer plugin (#3725)
  * Fixed: missing removed-plugins-file in setup.py build (#3653)
  * Changed: HLS streams to use rounded bandwidth names (#3721)
  * Removed: plugin for hitbox.tv / smashcast.tv (#3686), tvplayer.com (#3673)
- Remove streamlink-fix_removed_plugin_test.patch
* Wed May 19 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 2.1.1
  * Added: --interface, -4 / --ipv4 and -6 / --ipv6 (#3483)
  * Added: --niconico-purge-credentials (#3434)
  * Added: --twitcasting-password (#3505)
  * Added: Linux AppImages (#3611)
  * Added: pre-built man page to bdist wheels and sdist tarballs (#3459, #3510)
  * Added: plugin for ahaber.com.tr and atv.com.tr (#3484), nimo.tv (#3508)
  * Fixed: --player-http / --player-continuous-http HTTP server being bound to all interfaces (#3450)
  * Fixed: handling of languages without alpha_2 code when using pycountry (#3518)
  * Fixed: memory leak when calling streamlink.streams() (#3486)
  * Fixed: race condition in HLS related tests (#3454)
  * Fixed: --player-fifo issues on Windows with VLC or MPV (#3619)
  * Fixed: various plugins issues (see detailed changelog down below)
  * Removed: Windows portable (RosadinTV) (#3535)
  * Removed: plugin for micous.com (#3457), ntvspor.net (#3485), btsports (#3636)
  * Dependencies: set websocket-client to >=0.58.0 (#3634)
- Fix tests at build time (streamlink-fix_removed_plugin_test.patch, #3653)
* Thu Feb 18 2021 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * BREAKING: dropped support for Python 2 and Python 3.5 (#3232, #3269)
  * BREAKING: updated the Python version of the Windows installer to 3.8 (#3330)
  * Users of Windows 7 will need their system to be fully upgraded.
  * BREAKING: removed all deprecated CLI arguments (#3277, #3349)
  * BREAKING: replaced various subtitle muxing CLI arguments with --mux-subtitles (#3324)
  * BREAKING: sideloading faulty plugins will now raise an Exception (#3366)
  * BREAKING: changed trace logging timestamp format (#3273)
  * BREAKING/API: removed deprecated Session compat options (#3349)
  * BREAKING/API: removed deprecated custom Logger and LogRecord (#3273)
  * BREAKING/API: removed deprecated parameters from HLSStream.parse_variant_playlist (#3347)
  * BREAKING/API: removed plugin.api.support_plugin (#3398)
  * Added: new plugin for pluto.tv (#3363)
  * Added: support for HLS master playlist URLs to --stream-url / --json (#3300)
  * Added: --ffmpeg-fout for changing the output format of muxed streams (#2892)
  * Added: --ffmpeg-copyts and --ffmpeg-start-at-zero (#3404, #3413)
  * Added: --streann-url for iframe referencing (#3356)
  * Added: --niconico-timeshift-offset (#3425)
  * Fixed: duplicate stream names in DASH inputs (#3410)
  * Fixed: youtube live playback (#3268, #3372, #3428)
  * Fixed: --twitch-disable-reruns (#3375)
  * Fixed: various plugins issues (see detailed changelog down below)
  * Changed: {filename} variable in --player-args / -a to {playerinput} and made both optional (#3313)
  * Changed: and fixed streamlinkrc config file in the Windows installer (#3350)
  * Changed: MPV’s automated --title argument to --force-media-title (#3405)
  * Changed: HTML documentation theme to furo (#3335)
  * Removed: plugins for skai, kingkong, ellobo, trt/trtspor, tamago, streamme, metube, cubetv, willax
* Sat Dec  5 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 1.7.0:
  * Added: new plugins for micous.com, tv999.bg and cbsnews.com
  * Added: new embedded ad detection for Twitch streams (#3213)
  * Fixed: a few broken plugins and minor plugin issues (see changelog down below)
  * Fixed: arguments in config files were read too late before taking effect (#3255)
  * Fixed: Arte plugin returning too many streams and overriding primary ones (#3228)
  * Fixed: Twitch plugin error when stream metadata API response is empty (#3223)
  * Fixed: Zattoo login issues (#3202)
  * Changed: plugin request and submission guidelines (#3244)
  * Changed: refactored and cleaned up Twitch plugin (#3227)
  * Removed: platform=_ stream token request parameter from Twitch plugin (again) (#3220)
  * Removed: plugins for itvplayer, aljazeeraen, srgssr and dingittv
- Update to 1.6.0:
  * Fixed: lots of broken plugins and minor plugin issues (see changelog down below)
  * Fixed: embedded ads on Twitch with an ads workaround, removing pre-roll and mid-stream ads (#3173)
  * Fixed: read timeout error when filtering out HLS segments (#3187)
  * Fixed: twitch plugin logging incorrect low-latency status when pre-roll ads exist (#3169)
  * Fixed: crunchyroll auth logic (#3150)
  * Added: the --hls-playlist-reload-time parameter for customizing HLS playlist reload times (#2925)
  * Added: python -m streamlink invocation style support (#3174)
  * Added: plugin for mrt.com.mk (#3097)
  * Changed: yupptv plugin and replaced email+pass with id+token authentication (#3116)
  * Removed: plugins for vaughnlive, pandatv, douyutv, cybergame, europaplus and startv
* Fri Aug 21 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5.0:
  * plugins.nbcsports: fix embed_url_re (#2980)
  * plugins.olympicchannel: fix/rewrite (#2981)
  * plugins.foxtr: fix playervars_re (#3013)
  * plugins.huya: fix _hls_re (#3007)
  * plugins.ceskatelevize: add new api for some links (#2991)
  * plugins.beattv: remove plugin (#3053)
  * plugins.ard_live: fix / rewrite (#3052)
  * plugins.ard_mediathek: fix / update (#3049)
  * Streamlink was added to Windows Package Manager
  * plugins.tvplayer: Add missing platform key in the GET for stream_url (#2989)
  * plugins.btv: remove login and fix API URL (#3019)
  * plugins.n13tv: new plugin - replaces plugins.reshet (#3034)
  * plugins.reshet: plugin removal (#3000)
  * plugins.tvnbg: plugin removal (#3056)
  * plugins.adultswim: fix/rewrite (#2952)
  * ci: no test/documentation jobs on scheduled run (#3012)
  * cli.main: fix msecs format in logging output (#3025)
  * utils.l10n: fix pycountry language lookup (#3057)
  * plugins.nbcnews: new plugin for http://nbcnews.com/now (#2927)
  * plugins.showroom: use normal HLSStreams
  * docs: remove unimportant note / file
  * plugins.viasat: remove play.nova.bg domain
  * actions: fixed incorrect versions and use names for codecov (#2932)
  * plugins.filmon: use /tv/ url and raise PluginError for invalid channels
  * flake8: E741 ambiguous variable name
  * plugins.youtube: Fix isLive and signatureCipher (#3026)
  * plugins.facebook: use meta og:video:url and added basic title support (#3024)
  * plugins.picarto: fixed vod url detection
  * ci: fix pycountry issue temporarily with a fixed version
  * plugin.api.useragents: update User-Agent
  * docs/install: fix Windows package manager
  * plugins.mixer: remove plugin
  * ci: run scheduled tests, ignore coverage report
  * plugins.cdnbg: update plugin to support new sites, and remove old sites (#2912)
  * plugins.radionet: fix plugin so it works with new page format (#3018)
  * fixed typo
  * plugins.app17: update API (#2969)
  * Plugin.nicolive:resolve API format change (#3061)
  * plugins.twitch: fix call_subdomain (#2958)
  * plugins.bigo: use API for video URL (#3016)
  * plugins.nicolive: resolve new api format (#3039)
- remove env-script-interpreter.patch (obsolete)
* Mon Nov 25 2019 Simon Puchert <simonpuchert@alice.de>
- Update to version 1.3.0:
  * twitch.tv shenanigans, see #2680; authenticating via
  - -twitch-oauth-token has been disabled.
  * new plugins: albavision, news.now.com, twitcasting.tv, viu.tv,
    vlive.tv, willax.tv
- Refresh env-script-interpreter.patch
- Use the small tarball (without ffmpeg (etc.) Windows binaries).
* Wed Aug 21 2019 Simon Puchert <simonpuchert@alice.de>
- Update to version 1.2.0:
  * Multiple plugin fixes
  * Fixed single hyphen params at the beginning of --player-args (#2333)
  * --http-proxy will set the default value of --https-proxy to same as --http-proxy. (#2536)
  * DASH Streams will handle headers correctly (#2545)
  * the timestamp for FFMPEGMuxer streams will start with zero (#2559)
- Use fdupes to address duplicate file warnings.
* Thu Apr 11 2019 Simon Puchert <simonpuchert@alice.de>
- Add env-script-interpreter.patch to fix Rpmlint errors.
- Require python-pycountry instead of python-iso-639 and
  python-iso3166, as these packages are not available in Factory.
- Add dependencies according to the installation instructions
- Remove support for Leap 42.3 since it was broken anyway.
- Update to version 1.1.1:
  * no relevant changes
- Update to version 1.1.0:
  * plugin fixes, improvements and new plugin implementations
  * addition of the --twitch-disable-ads option
  * DASH stream improvements
  * documentation enhancements
  * addition of the {url} player title variable
  * default player title config for PotPlayer
* Wed Mar 13 2019 Simon Puchert <simonpuchert@alice.de>
- Update to version 1.0.0:
  * New icon / logo for Streamlink
  * Updated dependencies
  * Many plugin updates.
  * You can now provide a custom key URI to override HLS streams.
  * User agents for API communication have been updated
  * Synonyms have been added to sort "best" and "worst" streams.
  * Process output will no longer show if tty is unavailable
  * Improved terminal progress display for wide characters
  * Fixed a bug with dynamic playlists on playback
  * Fixed makeinstaller.sh
  * Old Livestreamer deprecations and API references were removed
  * Dependencies have been updated for Python
  * Newer and more common User-Agents are now used
  * Round the bitrates used for names of DASH streams.
  * URL have been added for better processing of HTML tags
  * Fixed sort and prog issue
  * Fixed crashing bug with player-continuous-http option
  * Make sure all dev dependencies (https://github.com/streamlink/streamlink/pull/2235)
  Breaking changes:
  * -r is a shorthand for --record instead of --rtmp-rtmpdump
  * A large number of unmaintained or NSFW plugins have been removed.
- Update to version 0.14.2:
  * Fixed Twitch OAuth request flow
  * Fix the tv3cat and vk plugins
  * VOD supported added to atresplayer plugin
  * Removed tv8cati and nineanime plugins
  * Added mjunoon.tv plugin
- Update to version 0.14.0:
  * Multiple plugin fixes
  * Bug fixes for DASH streams
  * Updated API call for api.utils hours_minutes_seconds
  * Updated documentation
  * Dict structures fix
  * Reformated help menu
  * Logger fix
* Sun Jun 24 2018 dmarcoux@posteo.de
- Update to version 0.13.0:
  * Initial MPEG DASH support has been added! (#1637) Many thanks to @beardypig
  * As always, a ton of plugin updates
  * Updates to our documentation (#1673)
  * Updates to our logging (#1752) as well as log --quiet options (#1744) (#1720)
  * Our release script has been updated (#1711)
  * Support for livestreams when using the --hls-duration option (#1710)
  * Allow streamlink to exit faster when using Ctrl+C (#1658)
  * Added an OpenCV Face Detection example (#1689)
- Remove streamlink-use-mpv.patch
* Tue Dec 19 2017 agraul@suse.com
- Update to version 0.9.0:
  * Updates to multiple plugins (electrecetv, tvplayer, Teve2,
    cnnturk, kanald)
- Update streamlink-use-mpv.patch
  * Refresh to apply on rebased code
* Sun Sep 17 2017 mpluskal@suse.com
- Update conditionals to resolve dependencies on Leap
* Tue Mar  7 2017 p.seiler@linuxmail.org
- update to version 0.3.2
- Added new Requirements:
  * python[3]-iso3166
  * python[3]-iso-639
  * python[3]-pycryptodome
* Wed Dec  7 2016 josipponjavic@gmail.com
- Initial package.
